Index: test/cctest/test-alloc.cc |
diff --git a/test/cctest/test-alloc.cc b/test/cctest/test-alloc.cc |
index efbb8d66c22649f16dec189e647c10c5a6e449b2..0d4ab886a3109b24be7e44c70e9370373a5b1b2e 100644 |
--- a/test/cctest/test-alloc.cc |
+++ b/test/cctest/test-alloc.cc |
@@ -198,11 +198,11 @@ TEST(CodeRange) { |
if (current_allocated < code_range_size / 10) { |
// Allocate a block. |
// Geometrically distributed sizes, greater than |
// Page::kMaxNonCodeHeapObjectSize (which is greater than code page area). |
// TODO(gc): instead of using 3 use some contant based on code_range_size |
// kMaxHeapObjectSize. |
size_t requested = |
- (Page::kMaxNonCodeHeapObjectSize << (Pseudorandom() % 3)) + |
+ (Page::kMaxRegularHeapObjectSize << (Pseudorandom() % 3)) + |
Pseudorandom() % 5000 + 1; |
size_t allocated = 0; |
Address base = code_range.AllocateRawMemory(requested, |
@@ -198,11 +198,11 @@ TEST(CodeRange) { |
// Allocate a block. |
// Geometrically distributed sizes, greater than |
- // Page::kMaxNonCodeHeapObjectSize (which is greater than code page area). |
+ // Page::kMaxRegularHeapObjectSize (which is greater than code page area). |
// TODO(gc): instead of using 3 use some contant based on code_range_size |
// kMaxHeapObjectSize. |